# Energy.tcl - takes output from dynamic analyses
# Units: kip, in
# Kevin Mackie, 2001/07/16
# mackie@ce.berkeley.edu
#
# Takes output from G3 dynamic analyses (called from bridge
# input file) and computes hysteretic energy from moment-curvature
# or force-displacement relationships

proc Energy {filef filed mult} {

set filef1 [open $filef "r"]
set filed1 [open $filed "r"]

set p_dispx 0.0
set p_loadx 0.0
set E_totalx 0.0
set p_dispy 0.0
set p_loady 0.0
set E_totaly 0.0
set p_dispz 0.0
set p_loadz 0.0
set E_totalz 0.0
while {-1 != [gets $filed1 lined1] } {
   set linef1 [gets $filef1]
   scan $lined1 "%e %e %e %e" axial_n temp_dispx temp_dispy temp_dispz
   scan $linef1 "%e %e %e %e" axial_n temp_loadx temp_loady temp_loadz

   # covert to rotation quantities (if necessary)
   set temp_dispx [expr $temp_dispx*$mult]
   set temp_dispy [expr $temp_dispy*$mult]
   set temp_dispz [expr $temp_dispz*$mult]

   set dxx [expr $temp_dispx-$p_dispx]
   set yhalfx [expr ($temp_loadx+$p_loadx)/2.0]
   set E_totalx [expr $E_totalx + $dxx*$yhalfx]
   set p_loadx $temp_loadx
   set p_dispx $temp_dispx

   set dxy [expr $temp_dispy-$p_dispy]
   set yhalfy [expr ($temp_loady+$p_loady)/2.0]
   set E_totaly [expr $E_totaly + $dxy*$yhalfy]
   set p_loady $temp_loady
   set p_dispy $temp_dispy

   set dxz [expr $temp_dispz-$p_dispz]
   set yhalfz [expr ($temp_loadz+$p_loadz)/2.0]
   set E_totalz [expr $E_totalz + $dxz*$yhalfz]
   set p_loadz $temp_loadz
   set p_dispz $temp_dispz
}
close $filef1
close $filed1

set einfo "$E_totalx $E_totaly $E_totalz"
return $einfo
}
