# FyUy.tcl - force-displacement pushovers
# Units: kip, in
# Kevin Mackie, 2001/07/16
# mackie@ce.berkeley.edu
#
# Takes output from G3 static analyses (called from bridge
# input file) and finds yield force and displacement information

proc FyUy {infile} {

# load yield force/displacement data and parse
# strip off gap related jumps later in pushover
set file [open [format "%s" $infile] "r"]
set max_disp 0.0
set dymonitor 4000.0
set max_load 0.0
set prev_load 0.0
set prev_disp 0.0

# line below will only work if there are no blank lines in output
while {-1 != [gets $file line] && [string length $line] > 4} {
   scan $line "%f %f" temp_load temp_disp

   while { abs($temp_load) < 1 } {
      gets $file line
      scan $line "%f %f" temp_load temp_disp
   }
   while { $temp_disp <= 0.5 } {
      gets $file line
      scan $line "%f %f" temp_load temp_disp
   }

   set static_slope [expr ($temp_load-$prev_load)/($temp_disp-$prev_disp)]
   if { [expr abs($temp_load)/abs($temp_disp)] <= $dymonitor && $static_slope >= 0 } {
      set dymonitor [expr abs($temp_load)/abs($temp_disp)]
      if { [expr abs($temp_load)] > $max_load} {
         set max_load [expr abs($temp_load)]
         set max_disp [expr abs($temp_disp)]
      }
   }
   set prev_load $temp_load
   set prev_disp $temp_disp
}

# go back and fit linear line through 0.66*fy
seek $file 0 start

set loc [expr $max_load*0.66]
set early 0
while {$early == 0} {
   if {-1 != [gets $file line] } {
      scan $line "%f %f" temp_load temp_disp
      if { [expr abs($temp_load)] > $loc} {
         set cr_load [expr abs($temp_load)]
         set cr_disp [expr abs($temp_disp)]
         set early 1
      }
   } else {
      set early 1
   }
}

# go back and find energy absorbed under maximum yield force
seek $file 0 start

set early 0
set Etotal 0.0
set p_load 0.0
set p_disp 0.0
while {$early == 0} {
   if {-1 != [gets $file line] } {
      scan $line "%f %f" temp_load temp_disp
      if { [expr abs($temp_disp)] <= $max_disp} {
         set dx [expr $temp_disp-$p_disp]
         set yhalf [expr ($temp_load+$p_load)/2.0]
         set Etotal [expr $Etotal + $dx*$yhalf]
         set p_load $temp_load
         set p_disp $temp_disp
      } else {
         set early 1
      }
   } else {
      set early 1
   }
}

close $file

set int_load [expr $max_load-($max_load-$cr_load)/2.0]
set uy [expr $int_load*$cr_disp/$cr_load]
set ucap [expr $max_disp/$uy]

set fyinfo "$uy $ucap $int_load $Etotal"
return $fyinfo

}
