# MaxVal.tcl - parses output file for maximum values
# Kevin Mackie, 2001/07/19
# mackie@ce.berkeley.edu
# University of California Berkeley
#
# Takes output file with specified number of columns of
# data and returns max value for each column
#
# special argument values are: 1 - last, keeps track of last value

proc MaxVal {filen cols special} {

for { set k 0 } { $k < $cols } { incr k } {
   set maxv($k) 0.0
}

# load data and parse
set file [open $filen "r"]
while {-1 != [gets $file line] } {
   if { [string length $line] > 5 } {
      set cmd [split $line]
      set kl [llength $cmd]
      if { $kl < $cols } {
         puts "Insufficient number of columns available"
         exit
      }

      for { set k 0 } { $k < $cols } { incr k } {
         set iv($k) [lindex $cmd $k]
         if { [expr abs($iv($k))] > [expr abs($maxv($k))] } {
            set maxv($k) $iv($k)
         }
      }
   }
}
close $file

set out ""
for { set k 0 } { $k < $cols } { incr k } {
   set out [concat $out $maxv($k)]
}

if { $special == 1 } {
   for { set k 0 } { $k < $cols } { incr k } {
      set out [concat $out $iv($k)]
   }
}
return $out

}