# AnalysisS.tcl - takes output from static analyses
# Units: kip, in
# Kevin Mackie, 2001/07/16
# mackie@ce.berkeley.edu
#
# Takes output from G3 static analyses (called from bridge
# input file) and finds yield moment and curvature information
# 
# dirc 1 - longitudinal
#      2 - transverse

proc MyKy {infilef infiled dirc} {

# ------------------------------------------------
# parsing for curvature yield data
set filef [open [format "%s" $infilef] "r"]
set filed [open [format "%s" $infiled] "r"]
set max_disp 0.0
set max_load 0.0
set prev_disp 0.0
set prev_load 0.0
while {-1 != [gets $filed lined] } {
   set linef [gets $filef]
   if { [string length $lined] > 5 } {
      if { $dirc == 1 } {
         scan $lined "%e %e %e %e" temp temp temp_disp temp
         scan $linef "%e %e %e %e" temp temp temp_load temp
      } else {
         scan $lined "%e %e %e %e" temp temp_disp temp temp
         scan $linef "%e %e %e %e" temp temp_load temp temp
      }

      while { abs($temp_load) < 50 } {
         gets $filed lined
         gets $filef linef
         if { [string length $lined] > 5 } {
            if { $dirc == 1 } {
               scan $lined "%e %e %e %e" temp temp temp_disp temp
               scan $linef "%e %e %e %e" temp temp temp_load temp
            } else {
               scan $lined "%e %e %e %e" temp temp_disp temp temp
               scan $linef "%e %e %e %e" temp temp_load temp temp
            }
         }
      }

      if { [expr $temp_disp-$prev_disp] == 0 } {
         set static_slope 10000
      } else {
         set static_slope [expr ($temp_load-$prev_load)/($temp_disp-$prev_disp)]
      }
      if { [expr abs($temp_load)] > $max_load && $static_slope >= 0} {
         set max_load [expr abs($temp_load)]
         set max_disp [expr abs($temp_disp)]
      }
      set prev_disp $temp_disp
      set prev_load $temp_load
   }
}
seek $filef 0 start
seek $filed 0 start

set loc [expr $max_load*0.66]
set early 0
while {$early == 0} {
   if {-1 != [gets $filef linef] } {
      set lined [gets $filed]
      if { [string length $lined] > 5 } {
         if { $dirc == 1 } {
            scan $lined "%e %e %e %e" temp temp temp_disp temp
            scan $linef "%e %e %e %e" temp temp temp_load temp
         } else {
            scan $lined "%e %e %e %e" temp temp_disp temp temp
            scan $linef "%e %e %e %e" temp temp_load temp temp
         }
         if { [expr abs($temp_load)] > $loc} {
            set cr_load [expr abs($temp_load)]
            set cr_disp [expr abs($temp_disp)]
            set early 1
         }
      }
   } else {
      set early 1
   }
}
close $filed
close $filef
set ky [expr $max_load*$cr_disp/$cr_load]
set kcap [expr $max_disp/$ky]

set fyinfo "$ky $kcap"
return $fyinfo

}
